@@ -1,5 +1,8 @@
 #' @title Formula construction
-#' @description Construction of the multivariate scglr formula.
+#' @description Helper function for building multivariate scglr formula.
+#' 
+#' NOTE: Interactions involving factors are not allowed for now.
+#' For interactions between two quantitative variables, use \code{I(x*y)} as usual.
 #' @export
 #' @param namesY a vector of character containing the names of the dependent variables.
 #' @param namesX a vector of character containing the names of the covariates (X) involved
@@ -8,15 +11,12 @@
 #' @return an object of class \code{Formula}.
 multivariateFormula <- function(namesY,namesX,namesAX=NULL)
 {
-  forml <- paste(namesY,collapse="+")
-  formr <- paste(namesX,collapse="+")
-  if(!is.null(namesAX)){
-   formr2 <- paste(namesAX,collapse="+")
-   form <- paste(paste(forml,"~",formr,sep=""),formr2,sep="|")
-   formula <- as.Formula(form)
-  }else{
-    formula <- as.Formula(paste(forml,"~",formr,sep=""))
+  form_lhs <- paste(namesY, collapse="+")
+  form_rhs <- paste(namesX, collapse="+")
+  if(!is.null(namesAX)) {
+    form_rhs <- paste(form_rhs, paste(namesAX, collapse="+"), sep="|")
   }
+  formula <- as.Formula(paste(form_lhs, "~", form_rhs, sep=""))
   environment(formula) <- .GlobalEnv
   return(formula)
 }
\ No newline at end of file
